@@ -4,12 +4,18 @@ from django.conf import settings
 from django.shortcuts import redirect, render
 from django.views.decorators.clickjacking import xframe_options_exempt
 
+from rest_framework.views import APIView
+
 import shopify
 
 from shopify_app.utils import get_shop_model
 from shopify_app.decorators import shopify_embed
 
 
+class ShopAPIView(APIView):
+    pass
+
+
 class InitTokenRequestView(View):
 
     redirect_path_name = ''
